@@ -3,7 +3,7 @@ package CGI::Session::Hidden;
 use strict;
 use MIME::Base64 qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub store {
     my( $self, $sid, $options, $data ) = @_;
@@ -97,6 +97,11 @@ Mattia Barbon <mbarbon@cpan.org>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+=head1 SOURCES
+
+The latest sources can be found on GitHub at
+L<http://github.com/mbarbon/cgi-session-hidden/tree>
+
 =head1 SEE ALSO
 
 L<CGI::Session|CGI::Session>
